==> lcov-server-1.1.6.tgz: package/distributed/bin/lcov-server.js <==
#!/usr/bin/env node
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

require('babel-polyfill');

var program = require('commander');
var http = require('http');
var https = require('https');
var fs = require('fs');
var Path = require('path');
var Url = require('url');
var updateNotifier = require('update-notifier');

var lcov = require('../lib/lcov');
var cobertura = require('../lib/cobertura');
var golang = require('../lib/golang');
var jacoco = require('../lib/jacoco');

var git = require('../lib/git');
var ci = require('../lib/ci');

var pkg = require('../package.json');

updateNotifier({ pkg: pkg }).notify();

program.version(pkg.version).option('-u, --upload [server]', 'Set the url to upload lcov data too', 'http://localhost:8080').option('-s, --serve', 'Pass this option to startup a lcov-server instance').option('-d, --db [db]', 'Set the db connection', 'mongodb://localhost:32768/lcov-server').option('-p, --parser <parser>', 'Set the parser value [lcov, cobertura, golang, jacoco], defaults to lcov', 'lcov').option('-bp, --basePath <path>', 'The path that defines the base directory where the files that were covered will be located').parse(process.argv);

var parser = program.parser,
    upload = program.upload,
    serve = program.serve,
    db = program.db,
    basePath = program.basePath;


if (parser && ['lcov', 'cobertura', 'golang', 'jacoco'].indexOf(parser) === -1) {
  console.error('parser ' + parser + ' not supported'); // eslint-disable-line
  process.exit(1);
}

if (serve) {
  process.env.MONGO_URL = process.env.MONGO_URL || db;

  require('../index');
} else {
  var parsedUrl = Url.parse(upload);

  var input = '';
  process.stdin.resume();
  process.stdin.setEncoding('utf8');
  process.stdin.on('data', function (chunk) {
    input += chunk;
  });
  process.stdin.on('end', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var env, output, _lcov, _git, i, path, options, operation, data, req;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            env = ci();
            output = {
              service_job_id: env.service_job_id,
              service_pull_request: env.service_pull_request,
              service_name: env.service_name,
              source_files: [],
              git: {
                commit: env.commit,
                branch: env.branch,
                message: env.message,
                committer_name: env.committer_name,
                committer_email: env.committer_email
              },
              run_at: new Date()
            };
            _lcov = {};
            _context.t0 = parser;
            _context.next = _context.t0 === 'cobertura' ? 6 : _context.t0 === 'golang' ? 10 : _context.t0 === 'jacoco' ? 14 : 18;
            break;

          case 6:
            _context.next = 8;
            return cobertura.parse(input);

          case 8:
            _lcov = _context.sent;
            return _context.abrupt('break', 22);

          case 10:
            _context.next = 12;
            return golang.parse(input);

          case 12:
            _lcov = _context.sent;
            return _context.abrupt('break', 22);

          case 14:
            _context.next = 16;
            return jacoco.parse(input);

          case 16:
            _lcov = _context.sent;
            return _context.abrupt('break', 22);

          case 18:
            _context.next = 20;
            return lcov.parse(input);

          case 20:
            _lcov = _context.sent;
            return _context.abrupt('break', 22);

          case 22:
            _context.next = 24;
            return git.parse();

          case 24:
            _git = _context.sent;


            // Go through and set the file contents
            for (i = 0; i < _lcov.length; i++) {
              path = basePath ? Path.resolve(process.cwd(), basePath, _lcov[i].file) : _lcov[i].file;


              _lcov[i].source = fs.readFileSync(path).toString('utf8');
              _lcov[i].title = _lcov[i].file.substring(_lcov[i].file.lastIndexOf('/') + 1, _lcov[i].file.length);
            }

            output['source_files'] = _lcov;
            output['git'] = Object.assign(output['git'], _git);

            options = {
              hostname: parsedUrl.hostname,
              port: parsedUrl.port || 80,
              path: '/api/upload',
              method: 'POST',
              headers: {
                'Content-Type': 'application/json'
              }
            };
            operation = http;
            data = '';


            if (parsedUrl.protocol == 'https:') {
              options.port = 443;
              operation = https;
            }

            req = operation.request(options, function (res) {
              res.on('data', function (chunk) {
                data += chunk;
              });
              res.on('end', function () {
                try {
                  var response = JSON.parse(data);
                  if (response.error) {
                    console.error(response.error); // eslint-disable-line
                  } else {
                    console.log('\n coverage sent successfully \uD83D\uDC9A \n'); // eslint-disable-line
                  }
                } catch (ex) {
                  console.log('\n uhoh something went wrong, ' + ex.toString()); // eslint-disable-line
                }
              });
            });

            req.write(JSON.stringify(output));
            req.end();

          case 35:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));
}

==> lcov-server-1.1.9.tgz: package/distributed/bin/lcov-server.js <==
#!/usr/bin/env node
'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

require('babel-polyfill');

var program = require('commander');
var updateNotifier = require('update-notifier');

var cli = require('../lib/cli');

var pkg = require('../package.json');

updateNotifier({ pkg: pkg }).notify();

program.version(pkg.version).option('-u, --upload [server]', 'Set the url to upload lcov data too', 'http://localhost:8080').option('-s, --serve', 'Pass this option to startup a lcov-server instance').option('-d, --db [db]', 'Set the db connection', 'mongodb://localhost:32768/lcov-server').option('-p, --parser <parser>', 'Set the parser value [lcov, cobertura, golang, jacoco], defaults to lcov', 'lcov').option('-bp, --basePath <path>', 'The path that defines the base directory where the files that were covered will be located').parse(process.argv);

var parser = program.parser,
    upload = program.upload,
    serve = program.serve,
    db = program.db,
    basePath = program.basePath;


if (parser && ['lcov', 'cobertura', 'golang', 'jacoco'].indexOf(parser) === -1) {
  console.error('parser ' + parser + ' not supported'); // eslint-disable-line
  process.exit(1);
}

if (serve) {
  process.env.MONGO_URL = process.env.MONGO_URL || db;

  require('../index');
} else {
  var input = '';
  process.stdin.resume();
  process.stdin.setEncoding('utf8');
  process.stdin.on('data', function (chunk) {
    input += chunk;
  });
  process.stdin.on('end', _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var response;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            try {
              response = cli({ parser: parser, input: input, url: upload, basePath: basePath });

              if (response.error) {
                console.error('coverage not sent with reason:\n ' + response.error); // eslint-disable-line
              } else {
                console.log('\n coverage sent successfully 💚 \n'); // eslint-disable-line
              }
            } catch (ex) {
              console.error('coverage could not be parsed with reason:\n ' + ex.toString()); // eslint-disable-line
            }

          case 1:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));
}
